Type: Package
Package: jsTreeR
Title: A Wrapper of the JavaScript Library 'jsTree'
Version: 2.6.0
Authors@R: c(
    person("Stéphane", "Laurent", , "laurent_step@outlook.fr", role = c("aut", "cre")),
    person("jQuery contributors", role = c("ctb", "cph"),
           comment = "jQuery"),
    person("Ivan", "Bozhanov", role = c("ctb", "cph"),
           comment = "jsTree"),
    person("Vedran", "Opacic", role = c("ctb", "cph"),
           comment = "jsTree bootstrap theme"),
    person("Avi", "Deitcher", role = c("ctb", "cph"),
           comment = "jsTreeGrid"),
    person("Philip", "Hutchison", role = c("ctb", "cph"),
           comment = "PDFObject"),
    person("Terence", "Eden", role = c("ctb", "cph"),
           comment = "SuperTinyIcons")
  )
Description: Creates interactive trees that can be included in 'Shiny'
    apps and R markdown documents. A tree allows to represent hierarchical
    data (e.g. the contents of a directory). Similar to the 'shinyTree'
    package but offers more features and options, such as the grid
    extension, restricting the drag-and-drop behavior, and settings for
    the search functionality. It is possible to attach some data to the
    nodes of a tree and then to get these data in 'Shiny' when a node is
    selected. Also provides a 'Shiny' gadget allowing to manipulate one or
    more folders, and a 'Shiny' module allowing to navigate in the server
    side file system.
License: GPL-3
URL: https://github.com/stla/jsTreeR
BugReports: https://github.com/stla/jsTreeR/issues
Depends: R (>= 2.10)
Imports: base64enc, fontawesome, htmltools, htmlwidgets, jquerylib,
        miniUI, R.utils, rstudioapi, shiny, shinyAce, stats, tools,
        utils
Suggests: jsonlite, magrittr
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.1
NeedsCompilation: no
Packaged: 2024-04-24 22:31:34 UTC; SDL96354
Author: Stéphane Laurent [aut, cre],
  jQuery contributors [ctb, cph] (jQuery),
  Ivan Bozhanov [ctb, cph] (jsTree),
  Vedran Opacic [ctb, cph] (jsTree bootstrap theme),
  Avi Deitcher [ctb, cph] (jsTreeGrid),
  Philip Hutchison [ctb, cph] (PDFObject),
  Terence Eden [ctb, cph] (SuperTinyIcons)
Maintainer: Stéphane Laurent <laurent_step@outlook.fr>
Repository: CRAN
Date/Publication: 2024-04-26 17:00:02 UTC
Built: R 4.6.0; ; 2026-04-29 04:12:47 UTC; unix
