# Generated by roxygen2: do not edit by hand

export(JS)
export(folderGadget)
export(jstree)
export(jstreeDestroy)
export(jstreeExample)
export(jstreeExamples)
export(jstreeOutput)
export(jstreeUpdate)
export(renderJstree)
export(saveWidget)
export(treeNavigatorServer)
export(treeNavigatorUI)
import(htmlwidgets)
import(miniUI)
import(shiny)
importFrom(R.utils,copyDirectory)
importFrom(base64enc,dataURI)
importFrom(fontawesome,fa_html_dependency)
importFrom(htmltools,htmlDependency)
importFrom(htmltools,tagList)
importFrom(htmltools,validateCssUnit)
importFrom(htmlwidgets,JS)
importFrom(htmlwidgets,saveWidget)
importFrom(htmlwidgets,shinyRenderWidget)
importFrom(htmlwidgets,shinyWidgetOutput)
importFrom(jquerylib,jquery_core)
importFrom(rstudioapi,getThemeInfo)
importFrom(rstudioapi,isAvailable)
importFrom(rstudioapi,navigateToFile)
importFrom(rstudioapi,sendToConsole)
importFrom(shiny,NS)
importFrom(shiny,bootstrapLib)
importFrom(shiny,moduleServer)
importFrom(shiny,observeEvent)
importFrom(shiny,reactiveVal)
importFrom(shiny,registerInputHandler)
importFrom(shiny,req)
importFrom(shiny,runApp)
importFrom(shinyAce,aceEditor)
importFrom(stats,setNames)
importFrom(tools,file_ext)
importFrom(utils,combn)
importFrom(utils,head)
importFrom(utils,packageVersion)
importFrom(utils,tail)
